@@ -76,6 +76,14 @@ class finspaceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace.html#finspace.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace/client/#close)
+        """
+
     def create_environment(
         self,
         *,
@@ -84,8 +92,8 @@ class finspaceClient(BaseClient):
         kmsKeyId: str = ...,
         tags: Mapping[str, str] = ...,
         federationMode: FederationModeType = ...,
-        federationParameters: "FederationParametersTypeDef" = ...,
-        superuserParameters: "SuperuserParametersTypeDef" = ...,
+        federationParameters: FederationParametersTypeDef = ...,
+        superuserParameters: SuperuserParametersTypeDef = ...,
         dataBundles: Sequence[str] = ...
     ) -> CreateEnvironmentResponseTypeDef:
         """
@@ -166,7 +174,7 @@ class finspaceClient(BaseClient):
         name: str = ...,
         description: str = ...,
         federationMode: FederationModeType = ...,
-        federationParameters: "FederationParametersTypeDef" = ...
+        federationParameters: FederationParametersTypeDef = ...
     ) -> UpdateEnvironmentResponseTypeDef:
         """
         Update your FinSpace environment.
