@@ -6,9 +6,9 @@ Type annotations for finspace service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_finspace.type_defs import CreateEnvironmentRequestRequestTypeDef
+    from mypy_boto3_finspace.type_defs import FederationParametersTypeDef
 
-    data: CreateEnvironmentRequestRequestTypeDef = {...}
+    data: FederationParametersTypeDef = {...}
     ```
 """
 import sys
@@ -23,86 +23,23 @@ else:
 
 
 __all__ = (
-    "CreateEnvironmentRequestRequestTypeDef",
-    "CreateEnvironmentResponseTypeDef",
-    "DeleteEnvironmentRequestRequestTypeDef",
-    "EnvironmentTypeDef",
     "FederationParametersTypeDef",
-    "GetEnvironmentRequestRequestTypeDef",
-    "GetEnvironmentResponseTypeDef",
-    "ListEnvironmentsRequestRequestTypeDef",
-    "ListEnvironmentsResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "ResponseMetadataTypeDef",
     "SuperuserParametersTypeDef",
+    "ResponseMetadataTypeDef",
+    "DeleteEnvironmentRequestRequestTypeDef",
+    "GetEnvironmentRequestRequestTypeDef",
+    "ListEnvironmentsRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateEnvironmentRequestRequestTypeDef",
-    "UpdateEnvironmentResponseTypeDef",
-)
-
-_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateEnvironmentRequestRequestTypeDef",
-    {
-        "name": str,
-    },
-)
-_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateEnvironmentRequestRequestTypeDef",
-    {
-        "description": str,
-        "kmsKeyId": str,
-        "tags": Mapping[str, str],
-        "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
-        "superuserParameters": "SuperuserParametersTypeDef",
-        "dataBundles": Sequence[str],
-    },
-    total=False,
-)
-
-
-class CreateEnvironmentRequestRequestTypeDef(
-    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
-):
-    pass
-
-
-CreateEnvironmentResponseTypeDef = TypedDict(
-    "CreateEnvironmentResponseTypeDef",
-    {
-        "environmentId": str,
-        "environmentArn": str,
-        "environmentUrl": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteEnvironmentRequestRequestTypeDef = TypedDict(
-    "DeleteEnvironmentRequestRequestTypeDef",
-    {
-        "environmentId": str,
-    },
-)
-
-EnvironmentTypeDef = TypedDict(
     "EnvironmentTypeDef",
-    {
-        "name": str,
-        "environmentId": str,
-        "awsAccountId": str,
-        "status": EnvironmentStatusType,
-        "environmentUrl": str,
-        "description": str,
-        "environmentArn": str,
-        "sageMakerStudioDomainUrl": str,
-        "kmsKeyId": str,
-        "dedicatedServiceAccountId": str,
-        "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
-    },
-    total=False,
+    "UpdateEnvironmentRequestRequestTypeDef",
+    "CreateEnvironmentRequestRequestTypeDef",
+    "CreateEnvironmentResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "GetEnvironmentResponseTypeDef",
+    "ListEnvironmentsResponseTypeDef",
+    "UpdateEnvironmentResponseTypeDef",
 )
 
 FederationParametersTypeDef = TypedDict(
@@ -118,51 +55,12 @@ FederationParametersTypeDef = TypedDict(
     total=False,
 )
 
-GetEnvironmentRequestRequestTypeDef = TypedDict(
-    "GetEnvironmentRequestRequestTypeDef",
+SuperuserParametersTypeDef = TypedDict(
+    "SuperuserParametersTypeDef",
     {
-        "environmentId": str,
-    },
-)
-
-GetEnvironmentResponseTypeDef = TypedDict(
-    "GetEnvironmentResponseTypeDef",
-    {
-        "environment": "EnvironmentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListEnvironmentsRequestRequestTypeDef = TypedDict(
-    "ListEnvironmentsRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-ListEnvironmentsResponseTypeDef = TypedDict(
-    "ListEnvironmentsResponseTypeDef",
-    {
-        "environments": List["EnvironmentTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "emailAddress": str,
+        "firstName": str,
+        "lastName": str,
     },
 )
 
@@ -177,12 +75,33 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SuperuserParametersTypeDef = TypedDict(
-    "SuperuserParametersTypeDef",
+DeleteEnvironmentRequestRequestTypeDef = TypedDict(
+    "DeleteEnvironmentRequestRequestTypeDef",
     {
-        "emailAddress": str,
-        "firstName": str,
-        "lastName": str,
+        "environmentId": str,
+    },
+)
+
+GetEnvironmentRequestRequestTypeDef = TypedDict(
+    "GetEnvironmentRequestRequestTypeDef",
+    {
+        "environmentId": str,
+    },
+)
+
+ListEnvironmentsRequestRequestTypeDef = TypedDict(
+    "ListEnvironmentsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
     },
 )
 
@@ -202,6 +121,25 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+EnvironmentTypeDef = TypedDict(
+    "EnvironmentTypeDef",
+    {
+        "name": str,
+        "environmentId": str,
+        "awsAccountId": str,
+        "status": EnvironmentStatusType,
+        "environmentUrl": str,
+        "description": str,
+        "environmentArn": str,
+        "sageMakerStudioDomainUrl": str,
+        "kmsKeyId": str,
+        "dedicatedServiceAccountId": str,
+        "federationMode": FederationModeType,
+        "federationParameters": FederationParametersTypeDef,
+    },
+    total=False,
+)
+
 _RequiredUpdateEnvironmentRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateEnvironmentRequestRequestTypeDef",
     {
@@ -214,7 +152,7 @@ _OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
         "name": str,
         "description": str,
         "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
+        "federationParameters": FederationParametersTypeDef,
     },
     total=False,
 )
@@ -226,10 +164,72 @@ class UpdateEnvironmentRequestRequestTypeDef(
     pass
 
 
+_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEnvironmentRequestRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEnvironmentRequestRequestTypeDef",
+    {
+        "description": str,
+        "kmsKeyId": str,
+        "tags": Mapping[str, str],
+        "federationMode": FederationModeType,
+        "federationParameters": FederationParametersTypeDef,
+        "superuserParameters": SuperuserParametersTypeDef,
+        "dataBundles": Sequence[str],
+    },
+    total=False,
+)
+
+
+class CreateEnvironmentRequestRequestTypeDef(
+    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
+):
+    pass
+
+
+CreateEnvironmentResponseTypeDef = TypedDict(
+    "CreateEnvironmentResponseTypeDef",
+    {
+        "environmentId": str,
+        "environmentArn": str,
+        "environmentUrl": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetEnvironmentResponseTypeDef = TypedDict(
+    "GetEnvironmentResponseTypeDef",
+    {
+        "environment": EnvironmentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListEnvironmentsResponseTypeDef = TypedDict(
+    "ListEnvironmentsResponseTypeDef",
+    {
+        "environments": List[EnvironmentTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateEnvironmentResponseTypeDef = TypedDict(
     "UpdateEnvironmentResponseTypeDef",
     {
-        "environment": "EnvironmentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "environment": EnvironmentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
